.. image:: images/deux_banner_text.png
  :width: 524
  :height: 207

**Multifactor Authentication for Django Rest Framework**

Contents
========

.. toctree::
    :maxdepth: 1

    copyright

.. toctree::
    :maxdepth: 2

    introduction
    userguide/index

.. toctree::
    :maxdepth: 1

    reference/index
    contributing
    changelog

Indices and tables
==================

* :ref:`modindex`
* :ref:`search`
